==> nextcloud-jitsi-v0.16.2.tar.gz: jitsi/l10n/tr.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "conferences",
    "Jitsi Integration" : "Jitsi bütünleştirmesi",
    "Conferences" : "Conferences",
    "Jitsi Integration (unofficial)" : "Jitsi bütünleştirmesi (resmi olmayan)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Bu uygulama Nextcloud için Jitsi conferences bütünleştirmesi sağlar.\n\nFeatures:\n- 🎥 Nextcloud içinden Jitsi ile kolay konferans düzenleme\n- 🔗 Paylaşılabilir konferans odası bağlantıları\n- 🔎 Genel aramada konferans odalarının görüntülenmesi\n- ✅ Bir konferansa katılmadan önce sistem sınaması\n\nLütfen [belgeleri](https://github.com/nextcloud/jitsi) okuyun.",
    "Loading …" : "Yükleniyor…",
    "Server URL (required)" : "Sunucu adresi (zorunlu)",
    "Help link (optional)" : "Yardım bağlantısı (isteğe bağlı)",
    "Display \"Join using the Jitsi app\"" : "\"Jitsi ile katılın\" iletisi görüntülensin",
    "JWT Secret (optional)" : "JWT parolası (isteğe bağlı)",
    "JWT App ID" : "JWT uygulama kodu",
    "JWT Audience (optional)" : "JWT dinleyicileri (isteğe bağlı)",
    "JWT Issuer (optional)" : "JWT yayıncısı (isteğe bağlı)",
    "save" : "kaydet",
    "saved" : "kaydedildi",
    "Saving …" : "Kaydediliyor…",
    "Please provide a Jitsi instance URL" : "Lütfen bir Jitsi kopyası adresi yazın",
    "The server URL must start with https://" : "Sunucu adresi https:// ile başlamalıdır",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Özel olarak ayrılmış bir Jitsi kopyası kurmanız önemle önerilir",
    "Please provide the App ID" : "Lütfen uygulama kodunu yazın",
    "Failed to save settings" : "Ayarlar kaydedilemedi",
    "Failed to load settings" : "Ayarlar yüklenemedi",
    "Conference rooms" : "Konferans odaları",
    "Conference" : "Konferans",
    "Conference left" : "Konferanstan çıkıldı",
    "Problems detected" : "Sorunlarla karşılaşıldı",
    "Your browser is non-optimal:" : "Web tarayıcınız uygun değil:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Ses ve görüntü kalitesi kötü olabilir. Güncel bir <b>Firefox/Chrome/Chromium</b> sürümü kullanmanız önerilir.",
    "Browser not supported" : "Web tarayıcı desteklenmiyor",
    "Show system check" : "Sistem denetimi görüntülensin",
    "Your name:" : "Adınız:",
    "Click here to join" : "Katılmak için buraya tıklayın",
    "Start muted" : "Başlangıçta mikrofon kapatılsın",
    "Start with camera off" : "Başlangıçta kamera kapatılsın",
    "Join with desktop app" : "Masaüstü uygulaması ile katıl",
    "Join with mobile app" : "Mobil uygulama ile katıl",
    "App button not working?" : "Uygulama düğmesi çalışmıyor mu?",
    "Download the desktop app here ↗" : "Masaüstü uygulamasını buradan indirin ↗",
    "The mobile app is available via the app store of your choice." : "Mobil uygulamayı kullanmayı yeğlediğiniz uygulama mağazasında bulabilirsiniz.",
    "After successful installation try the button again." : "Kurulumu tamamladıktan sonra düğmeyi yeniden deneyin.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Hala çalışmıyor mu? Aşağıdaki bağlantıyı kopyalayıp Jitsi uygulamasının başlangıç sayfasındaki giriş alanına yapıştırın.",
    "Link copied" : "Bağlantı kopyalandı",
    "Cannot copy, please copy the link manually" : "Kopyalanamadı. Lütfen bağlantıyı el ile kopyalayın",
    "Copy to clipboard" : "Panoya kopyala",
    "Browser" : "Web tarayıcı",
    "non-optimal" : "uygun değil",
    "not supported" : "desteklenmiyor",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Ses ve görüntü kalitesi kötü olabilir.<br>Güncel bir <b>Firefox / Chrome / Chromium</b> sürümü kullanmanız önerilir.",
    "Help" : "Yardım",
    "Camera" : "Kamera",
    "Name of the new room" : "Yeni odanın adı",
    "No conference rooms yet" : "Henüz bir konferans odası yok",
    "Create the first room:" : "İlk odayı oluşturun:",
    "Microphone" : "Mikrofon",
    "Join" : "Katıl",
    "Delete room" : "Odayı sil",
    "Room not found" : "Oda bulunamadı",
    "Please check the link/URL and ask your host" : "Lütfen bağlantı ya da adresi denetleyip konferans sorumlusu ile görüşün ",
    "Audio output" : "Ses çıkışı",
    "Play test sound" : "Deneme sesini çal",
    "System check" : "Sistem denetimi",
    "Got issues?" : "Sorun mu var?",
    "Known problems / what you can try" : "Bilinen sorunlar / yapabilecekleriniz",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Ekranın üst bölümünde istenilen mikrofon/kamera erişimi izinlerini kabul edin",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Adres çubuğunun yanındaki simgeye tıklayarak mikrofon/kamera erişim izinlerini denetleyin. Ardından sayfayı yeniden yükleyin.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• DroidCam kullanıyorsanız: Mobil kamerayı bağlayıp sayfayı yeniden yükleyin",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Jitsi uygulaması ile katılmayı deneyin (sayfanın alt bölümündeki yönergeleri izleyin)",
    "No camera/microphone access" : "Kamera/mikrofon erişimi yok",
    "Review your browser camera and microphone access settings" : "Web tarayıcınızın kamera ve mikrofon erişimi ayarlarını gözden geçirin",
    "Click here for {browser} instructions" : "{browser} yönergeleri için buraya tıklayın",
    "Does not work?" : "İşe yaramadı mı?",
    "Click here for troubleshooting help" : "Sorun çözme yardımı için buraya tıklayın",
    "Conferences app not yet configured" : "Conferences uygulaması henüz yapılandırılmamış",
    "Please contact your administrator to set up the conferences app." : "Lütfen Conferences uygulamasını kurması için BT yöneticinizle görüşün.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Web tarayıcınız (%1$s) eskimiş ve<br>artık desteklenmiyor",
    "It is recommended to use the latest version of one of the following browsers:" : "Şu web tarayıcılardan birinin güncel sürümünü kullanmanız önerilir:"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-jitsi-v0.18.0.tar.gz: jitsi/l10n/tr.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "conferences",
    "Jitsi Integration" : "Jitsi bütünleştirmesi",
    "Conferences" : "Conferences",
    "Jitsi Integration (unofficial)" : "Jitsi bütünleştirmesi (resmi olmayan)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Bu uygulama Nextcloud için Jitsi conferences bütünleştirmesi sağlar.\n\nFeatures:\n- 🎥 Nextcloud içinden Jitsi ile kolay konferans düzenleme\n- 🔗 Paylaşılabilir konferans odası bağlantıları\n- 🔎 Genel aramada konferans odalarının görüntülenmesi\n- ✅ Bir konferansa katılmadan önce sistem sınaması\n\nLütfen [belgeleri](https://github.com/nextcloud/jitsi) okuyun.",
    "Loading …" : "Yükleniyor…",
    "Server URL (required)" : "Sunucu adresi (zorunlu)",
    "Help link (optional)" : "Yardım bağlantısı (isteğe bağlı)",
    "Display \"Join using the Jitsi app\"" : "\"Jitsi ile katılın\" iletisi görüntülensin",
    "JWT Secret (optional)" : "JWT parolası (isteğe bağlı)",
    "JWT App ID" : "JWT uygulama kodu",
    "JWT Audience (optional)" : "JWT dinleyicileri (isteğe bağlı)",
    "JWT Issuer (optional)" : "JWT yayıncısı (isteğe bağlı)",
    "save" : "kaydet",
    "saved" : "kaydedildi",
    "Saving …" : "Kaydediliyor…",
    "Please provide a Jitsi instance URL" : "Lütfen bir Jitsi kopyası adresi yazın",
    "The server URL must start with https://" : "Sunucu adresi https:// ile başlamalıdır",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Özel olarak ayrılmış bir Jitsi kopyası kurmanız önemle önerilir",
    "Please provide the App ID" : "Lütfen uygulama kodunu yazın",
    "Failed to save settings" : "Ayarlar kaydedilemedi",
    "Failed to load settings" : "Ayarlar yüklenemedi",
    "Conference rooms" : "Konferans odaları",
    "Conference" : "Konferans",
    "Conference left" : "Konferanstan çıkıldı",
    "Problems detected" : "Sorunlarla karşılaşıldı",
    "Your browser is non-optimal:" : "Tarayıcınız uygun değil:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Ses ve görüntü kalitesi kötü olabilir. Güncel bir <b>Firefox/Chrome/Chromium</b> sürümü kullanmanız önerilir.",
    "Browser not supported" : "Tarayıcı desteklenmiyor",
    "Show system check" : "Sistem denetimi görüntülensin",
    "Your name:" : "Adınız:",
    "Click here to join" : "Katılmak için buraya tıklayın",
    "Start muted" : "Başlangıçta mikrofon kapatılsın",
    "Start with camera off" : "Başlangıçta kamera kapatılsın",
    "Join with desktop app" : "Masaüstü uygulaması ile katıl",
    "Join with mobile app" : "Mobil uygulama ile katıl",
    "App button not working?" : "Uygulama düğmesi çalışmıyor mu?",
    "Download the desktop app here ↗" : "Masaüstü uygulamasını buradan indirin ↗",
    "The mobile app is available via the app store of your choice." : "Mobil uygulamayı kullanmayı yeğlediğiniz uygulama mağazasında bulabilirsiniz.",
    "After successful installation try the button again." : "Kurulumu tamamladıktan sonra düğmeyi yeniden deneyin.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Hala çalışmıyor mu? Aşağıdaki bağlantıyı kopyalayıp Jitsi uygulamasının başlangıç sayfasındaki giriş alanına yapıştırın.",
    "Link copied" : "Bağlantı kopyalandı",
    "Cannot copy, please copy the link manually" : "Kopyalanamadı. Lütfen bağlantıyı el ile kopyalayın",
    "Copy to clipboard" : "Panoya kopyala",
    "Browser" : "Tarayıcı",
    "non-optimal" : "uygun değil",
    "not supported" : "desteklenmiyor",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Ses ve görüntü kalitesi kötü olabilir.<br>Güncel bir <b>Firefox / Chrome / Chromium</b> sürümü kullanmanız önerilir.",
    "Help" : "Yardım",
    "Camera" : "Kamera",
    "Name of the new room" : "Yeni odanın adı",
    "No conference rooms yet" : "Henüz bir konferans odası yok",
    "Create the first room:" : "İlk odayı oluşturun:",
    "Microphone" : "Mikrofon",
    "Join" : "Katıl",
    "Delete room" : "Odayı sil",
    "Room not found" : "Oda bulunamadı",
    "Please check the link/URL and ask your host" : "Lütfen bağlantı ya da adresi denetleyip konferans sorumlusu ile görüşün ",
    "Audio output" : "Ses çıkışı",
    "Play test sound" : "Deneme sesini çal",
    "System check" : "Sistem denetimi",
    "Got issues?" : "Sorun mu var?",
    "Known problems / what you can try" : "Bilinen sorunlar / yapabilecekleriniz",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Ekranın üst bölümünde istenilen mikrofon/kamera erişimi izinlerini kabul edin",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Adres çubuğunun yanındaki simgeye tıklayarak mikrofon/kamera erişim izinlerini denetleyin. Ardından sayfayı yeniden yükleyin.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• DroidCam kullanıyorsanız: Mobil kamerayı bağlayıp sayfayı yeniden yükleyin",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Jitsi uygulaması ile katılmayı deneyin (sayfanın alt bölümündeki yönergeleri izleyin)",
    "No camera/microphone access" : "Kamera/mikrofon erişimi yok",
    "Review your browser camera and microphone access settings" : "Tarayıcınızın kamera ve mikrofon erişimi ayarlarını gözden geçirin",
    "Click here for {browser} instructions" : "{browser} yönergeleri için buraya tıklayın",
    "Does not work?" : "İşe yaramadı mı?",
    "Click here for troubleshooting help" : "Sorun çözme yardımı için buraya tıklayın",
    "Conferences app not yet configured" : "Conferences uygulaması henüz yapılandırılmamış",
    "Please contact your administrator to set up the conferences app." : "Lütfen Conferences uygulamasını kurması için BT yöneticinizle görüşün.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Tarayıcınız (%1$s) eskimiş ve<br>artık desteklenmiyor",
    "It is recommended to use the latest version of one of the following browsers:" : "Şu tarayıcılardan birinin güncel sürümünü kullanmanız önerilir:"
},
"nplurals=2; plural=(n > 1);");
